@@ -7,7 +7,6 @@ from parameterized import parameterized
 from integration.config.service_names import (
     ARM,
     CODE_DEPLOY,
-    EPHEMERAL_STORAGE,
     EVENT_INVOKE_CONFIG,
     HTTP_API,
     KMS,
@@ -275,29 +274,6 @@ class TestBasicFunction(BaseTest):
             "Expecting tracing config mode to be set to PassThrough.",
         )
 
-    @parameterized.expand(
-        [
-            "single/function_with_ephemeral_storage",
-        ]
-    )
-    @skipIf(
-        current_region_does_not_support([EPHEMERAL_STORAGE]),
-        "Lambda ephemeral storage is not supported in this testing region",
-    )
-    def test_function_with_ephemeral_storage(self, file_name):
-        """
-        Creates a basic function with ephemeral storage
-        """
-        self.create_and_verify_stack(file_name)
-
-        function_id = self.get_physical_id_by_logical_id("MyLambdaFunction")
-
-        function_configuration_result = self.client_provider.lambda_client.get_function_configuration(
-            FunctionName=function_id
-        )
-
-        self.assertEqual(function_configuration_result.get("EphemeralStorage", {}).get("Size", 0), 1024)
-
     def _assert_invoke(self, lambda_client, function_name, qualifier=None, expected_status_code=200):
         """
         Assert if a Lambda invocation returns the expected status code
