@@ -14,7 +14,7 @@ from samtranslator.model.exceptions import (
     InvalidResourcePropertyTypeException,
 )
 from samtranslator.model.tags.resource_tagging import get_tag_list
-from samtranslator.model.types import IS_DICT, IS_STR, Validator, any_type, is_type
+from samtranslator.model.types import IS_DICT, IS_STR, PassThrough, Validator, any_type, is_type
 from samtranslator.plugins import LifeCycleEvents
 
 RT = TypeVar("RT", bound=BaseModel)  # return type
@@ -74,6 +74,14 @@ class PassThroughProperty(PropertyType):
         super().__init__(required, any_type(), False)
 
 
+class MutatedPassThroughProperty(PassThroughProperty):
+    """
+    Mutated pass-through property.
+
+    SAM Translator may read and add/remove/modify the value before passing it to underlaying CFN resources.
+    """
+
+
 class GeneratedProperty(PropertyType):
     """
     Property of a generated CloudFormation resource.
@@ -105,7 +113,7 @@ class Resource(ABC):
     # TODO: Make `Resource` an abstract class and not giving `resource_type`/`property_types` initial value.
     resource_type: str = None  # type: ignore
     property_types: Dict[str, PropertyType] = None  # type: ignore
-    _keywords = ["logical_id", "relative_id", "depends_on", "resource_attributes"]
+    _keywords = {"logical_id", "relative_id", "depends_on", "resource_attributes"}
 
     # For attributes in this list, they will be passed into the translated template for the same resource itself.
     _supported_resource_attributes = ["DeletionPolicy", "UpdatePolicy", "Condition", "UpdateReplacePolicy", "Metadata"]
@@ -122,6 +130,12 @@ class Resource(ABC):
     # }
     runtime_attrs: Dict[str, Callable[["Resource"], Any]] = {}  # TODO: replace Any with something more explicit
 
+    # When "validate_setattr" is True, we cannot change the value of any class variables after instantiation unless they
+    # are in "property_types" or "_keywords". We can set this to False in the inheriting class definition so we can
+    # update other class variables as well after instantiation.
+    validate_setattr: bool = True
+    Tags: Optional[PassThrough]
+
     def __init__(
         self,
         logical_id: Optional[Any],
@@ -313,7 +327,7 @@ class Resource(ABC):
         :param value: the value of the attribute to be set
         :raises InvalidResourceException: if an invalid property is provided
         """
-        if name in self._keywords or name in self.property_types:
+        if (name in self._keywords or name in self.property_types) or not self.validate_setattr:
             return super().__setattr__(name, value)
 
         raise InvalidResourceException(
@@ -337,10 +351,8 @@ class Resource(ABC):
         except ValidationError as e:
             error_properties: str = ""
             with suppress(KeyError):
-                error_properties = ", ".join([str(error["loc"][0]) for error in e.errors()])
-            raise InvalidResourceException(
-                self.logical_id, f"Given resource property '{error_properties}' is invalid"
-            ) from e
+                error_properties = ".".join(str(x) for x in e.errors()[0]["loc"])
+            raise InvalidResourceException(self.logical_id, f"Property '{error_properties}' is invalid.") from e
 
     def validate_properties(self) -> None:
         """Validates that the required properties for this Resource have been populated, and that all properties have
@@ -428,6 +440,19 @@ class Resource(ABC):
                 attributes[resource_attribute] = self.resource_attributes.get(resource_attribute)
         return attributes
 
+    def assign_tags(self, tags: Dict[str, Any]) -> None:
+        """
+        Assigns tags to the resource. This function assumes that generated resources always have
+        the tags property called `Tags` that takes a list of key-value objects.
+
+        Override this function if the above assumptions do not apply to the resource (e.g. different
+        property name or type (see e.g. 'AWS::ApiGatewayV2::Api').
+
+        :param tags: Dictionary of tags to be assigned to the resource
+        """
+        if "Tags" in self.property_types:
+            self.Tags = get_tag_list(tags)
+
 
 class ResourceMacro(Resource, metaclass=ABCMeta):
     """A ResourceMacro object represents a CloudFormation macro. A macro appears in the CloudFormation template in the
@@ -531,6 +556,25 @@ class SamResourceMacro(ResourceMacro, metaclass=ABCMeta):
         # customer's knowledge.
         return get_tag_list(sam_tag) + get_tag_list(additional_tags) + get_tag_list(tags)
 
+    @staticmethod
+    def propagate_tags(
+        resources: List[Resource], tags: Optional[Dict[str, Any]], propagate_tags: Optional[bool] = False
+    ) -> None:
+        """
+        Propagates tags to the resources.
+
+        :param propagate_tags: Whether we should pass the tags to generated resources.
+        :param resources: List of generated resources
+        :param tags: dictionary of tags to propagate to the resources.
+
+        :return: None
+        """
+        if not propagate_tags or not tags:
+            return
+
+        for resource in resources:
+            resource.assign_tags(tags)
+
     def _check_tag(self, reserved_tag_name, tags):  # type: ignore[no-untyped-def]
         if reserved_tag_name in tags:
             raise InvalidResourceException(
@@ -626,6 +670,7 @@ __all__: List[str] = [
     "PropertyType",
     "Property",
     "PassThroughProperty",
+    "MutatedPassThroughProperty",
     "Resource",
     "ResourceMacro",
     "SamResourceMacro",
